Learn R Programming

PhaseGMM (version 0.1.0)

computing_GMM_estimator: GMM estimator combining moment-corrected and phase-function equations

Description

Computes Generalized Method of Moments (GMM) estimators by combining moment-corrected estimating equations and phase-function estimating equations. The GMM weighting matrix is estimated via a cluster bootstrap that accounts for uncertainty in estimating the measurement error covariance.

Usage

computing_GMM_estimator(
  W,
  y,
  Zmat,
  weight_method = c("uniform", "minimax", "quasi-likelihood"),
  B = 100,
  t_grid_length = 1000
)

Value

A list with components:

est

Numeric matrix of GMM estimates; one column per weight choice.

CV_boot

Array of bootstrap covariance matrices used in GMM.

Arguments

W

Numeric array of dimension n x p x J containing replicate measurements of contaminated covariates.

y

Numeric vector of length n containing the response.

Zmat

Numeric matrix of dimension n x q containing error-free covariates.

B

Integer specifying the number of bootstrap replicates.

t_grid_length

Integer specifying the length of optimal t for computational intergration.