Learn R Programming

PhaseGMM (version 0.1.0)

computing_corrected_estimator: Compute the corrected estimator via estimating equations

Description

This function computes the corrected estimator for a linear model with measurement error in covariates by solving the corrected estimating equations using a nonlinear root-finding algorithm.

Usage

computing_corrected_estimator(y, Wbar, Zmat, estSigmaU_bar, beta_in = NULL)

Value

Numeric vector of length p + q, the corrected estimator.

Arguments

y

Numeric vector of length n. Response variable.

Wbar

Numeric matrix of dimension n × p. Error-prone covariates at the averaged (replicate) level.

Zmat

Numeric matrix of dimension n × q. Error-free covariates (including intercept if applicable).

estSigmaU_bar

Measurement error variance/covariance associated with the averaged covariates. Can be n × p × p or n × 1.

beta_in

Optional numeric vector of length p + q. Initial value for the estimating equation solver.

Details

The estimator is obtained by solving $$E_n(\beta) = 0$$ where E_n is the corrected estimating equation implemented in estim_eq_corrected().

See Also

estim_eq_corrected