Learn R Programming

PhaseGMM (version 0.1.0)

estim_eq_corrected: Moment-corrected estimating equations for measurement error regression

Description

Constructs the moment-corrected estimating equations for a linear regression model with averaged error-prone covariates and error-free covariates.

Usage

estim_eq_corrected(y, Wbar, Zmat, b_in, estSigmaU_bar)

Value

Numeric vector of length p + q containing the stacked estimating equations.

Arguments

y

Numeric vector of length n containing the response.

Wbar

Numeric matrix of dimension n x p containing averaged error-prone covariates.

Zmat

Numeric matrix of dimension n x q containing error-free covariates (including an intercept if required).

b_in

Numeric vector of length p + q containing the regression coefficients at which the estimating equations are evaluated.

estSigmaU_bar

Numeric array of dimension n x p x p (or numeric vector in the univariate case) containing measurement error covariance estimates.