Learn R Programming

PhaseGMM (version 0.1.0)

print.eiv_mlr: Print Method for eiv_mlr Objects

Description

Displays a concise summary of an errors-in-variables linear model fit.

Usage

# S3 method for eiv_mlr
print(x, ...)

Value

Invisibly returns the input object x of class "eiv_mlr". This function is called for its side effect of printing a summary of the model.

Arguments

x

An object of class "eiv_mlr".

...

Not used.