Computes Generalized Method of Moments (GMM) estimators by combining moment-corrected estimating equations and phase-function estimating equations. The GMM weighting matrix is estimated via a cluster bootstrap that accounts for uncertainty in estimating the measurement error covariance.
computing_GMM_estimator(
W,
y,
Zmat,
weight_method = c("uniform", "minimax", "quasi-likelihood"),
B = 100,
t_grid_length = 1000
)A list with components:
Numeric matrix of GMM estimates; one column per weight choice.
Array of bootstrap covariance matrices used in GMM.
Numeric array of dimension n x p x J containing replicate
measurements of contaminated covariates.
Numeric vector of length n containing the response.
Numeric matrix of dimension n x q containing error-free
covariates.
Integer specifying the number of bootstrap replicates.
Integer specifying the length of optimal t for computational intergration.