This function computes the corrected estimator for a linear model with measurement error in covariates by solving the corrected estimating equations using a nonlinear root-finding algorithm.
computing_corrected_estimator(y, Wbar, Zmat, estSigmaU_bar, beta_in = NULL)Numeric vector of length p + q, the corrected estimator.
Numeric vector of length n. Response variable.
Numeric matrix of dimension n × p. Error-prone
covariates at the averaged (replicate) level.
Numeric matrix of dimension n × q. Error-free
covariates (including intercept if applicable).
Measurement error variance/covariance associated
with the averaged covariates. Can be n × p × p or n × 1.
Optional numeric vector of length p + q. Initial
value for the estimating equation solver.
The estimator is obtained by solving
$$E_n(\beta) = 0$$
where E_n is the corrected estimating equation implemented in
estim_eq_corrected().
estim_eq_corrected