Constructs the moment-corrected estimating equations for a linear regression model with averaged error-prone covariates and error-free covariates.
estim_eq_corrected(y, Wbar, Zmat, b_in, estSigmaU_bar)Numeric vector of length p + q containing the stacked
estimating equations.
Numeric vector of length n containing the response.
Numeric matrix of dimension n x p containing averaged
error-prone covariates.
Numeric matrix of dimension n x q containing error-free
covariates (including an intercept if required).
Numeric vector of length p + q containing the regression
coefficients at which the estimating equations are evaluated.
Numeric array of dimension n x p x p (or numeric
vector in the univariate case) containing measurement error covariance
estimates.