Constructs a stacked system of estimating equations combining moment-corrected score equations and phase-function score equations.
estim_eq_correctedAndPhase(
Wbar,
Zmat,
y,
S_y,
C_y,
b_in,
estWeight,
estSigmaU_bar,
t
)Numeric vector containing the stacked estimating equations of length
2 * (p + q).
Numeric matrix of dimension n x p containing averaged
error-prone covariates.
Numeric matrix of dimension n x q containing error-free
covariates (including an intercept if required).
Numeric vector of length n containing the response.
Numeric vector containing precomputed sine terms for the phase function.
Numeric vector containing precomputed cosine terms for the phase function.
Numeric vector of length p + q at which the estimating
equations are evaluated.
Numeric vector of weights used in the phase-function component.
Numeric array of dimension n x p x p containing
measurement error covariance estimates.
Numeric vector of frequency values used in the phase function.